@@ -16,11 +16,14 @@
 #endif /* HAVE_CONFIG_H */
 
 #ifdef AUTH_MYSQL
-static const char rcsid[] = "$Id: auth_mysql.c,v 1.19 2001/06/05 15:24:04 chris Exp $";
+static const char rcsid[] = "$Id: auth_mysql.c,v 1.21 2001/06/24 00:15:55 chris Exp $";
 
 #include <sys/types.h> /* BSD needs this here, apparently. */
 
+#ifdef CRYPT_FUNCTION_IN_CRYPT_H
 #include <crypt.h>
+#endif
+
 #include <grp.h>
 #include <pwd.h>
 #include <mysql.h>
@@ -28,6 +31,7 @@ static const char rcsid[] = "$Id: auth_mysql.c,v 1.19 2001/06/05 15:24:04 chris
 #include <stdlib.h>
 #include <string.h>
 #include <syslog.h>
+#include <unistd.h>
 
 #include "auth_mysql.h"
 #include "authswitch.h"
@@ -443,7 +447,7 @@ authcontext auth_mysql_new_user_pass(const char *user, const char *pass) {
         return NULL;
     }
 
-    query = (char*)malloc(l = (sizeof(user_pass_query_template) + strlen(user) * 2 + 1 + 34));
+    query = (char*)malloc(l = (sizeof(user_pass_query_template) + strlen(user) * 2));
     x = (char*)malloc(strlen(local_part) * 2 + 1);
     y = (char*)malloc(strlen(domain) * 2 + 1);
     if (!query || !x || !y) goto fail;
