@@ -43,7 +43,7 @@
 #endif /* HAVE_CONFIG_H */
 
 #ifdef AUTH_OTHER
-static const char rcsid[] = "$Id: auth_other.c,v 1.4 2001/05/03 00:20:56 chris Exp $";
+static const char rcsid[] = "$Id: auth_other.c,v 1.7 2001/06/10 21:52:10 chris Exp $";
 
 #include <sys/types.h>
 
@@ -72,11 +72,12 @@ char *auth_program;
 time_t authchild_start_time;
 uid_t authchild_uid;
 gid_t authchild_gid;
-volatile pid_t authchild_pid;
+volatile pid_t authchild_pid, authchild_died;
+volatile int authchild_status;
 struct timeval authchild_timeout;
 
 /* File descriptors used to talk to child. */
-int authchild_wr, authchild_rd;
+volatile int authchild_wr, authchild_rd;
 
 /* dump:
  * Debugging method.
@@ -140,7 +141,7 @@ int tvcmp(const struct timeval *t1, const struct timeval *t2) {
 int auth_other_start_child() {
     int p1[2], p2[2];
     char *argv[2] = {auth_program, NULL};
-    char *envp[2] = {"PATH=/bin",  /* XXX path? */
+    char *envp[3] = {"PATH=/bin",  /* XXX path? */
                      "TPOP3D_CONTEXT=auth_other", NULL};
 
     /* Generate pipes to talk to the child. */
@@ -163,10 +164,10 @@ int auth_other_start_child() {
         case 0:
             if (setgid(authchild_gid) == -1) {
                 print_log(LOG_ERR, "auth_other_start_child: setgid(%d): %m", (int)authchild_gid);
-                exit(1);
+                _exit(1);
             } else if (setuid(authchild_uid) == -1) {
                 print_log(LOG_ERR, "auth_other_start_child: setuid(%d): %m", (int)authchild_uid);
-                exit(1);
+                _exit(1);
             }
             
             /* Child. */
@@ -179,7 +180,7 @@ int auth_other_start_child() {
             execve(auth_program, argv, envp);
 
             /* Failed. */
-            exit(1);
+            _exit(1);
 
             break;
             
@@ -408,8 +409,10 @@ stringmap auth_other_recv_response() {
                         goto fail;
 
                     case -1:
-                        print_log(LOG_ERR, _("auth_other_recv_response: read: %m; killing child"));
-                        goto fail;
+                        if (errno != EINTR) {
+                            print_log(LOG_ERR, _("auth_other_recv_response: read: %m; killing child"));
+                            goto fail;
+                        } else break;
 
                     default:
                         p += rr;
