@@ -7,7 +7,7 @@
  */
 
 static const char copyright[] = "$Copyright: (c) 2001 Chris Lightfoot. All rights reserved. $";
-static const char rcsid[] = "$Id: main.c,v 1.48 2001/06/10 21:52:10 chris Exp $";
+static const char rcsid[] = "$Id: main.c,v 1.49 2001/06/23 16:54:59 chris Exp $";
 
 #ifdef HAVE_CONFIG_H
 #include "configuration.h"
@@ -162,7 +162,7 @@ void fork_child(connection *C, listitem *i) {
     listitem J;
     item *t;
     post_fork = 1; /* This is right. See below. */
-    muntrace();
+    /* muntrace(); */ /* Memory debugging on glibc systems. */
     switch(fork()) {
         case 0:
             /* Child. Dispose of listeners and connections other than this
@@ -452,7 +452,7 @@ int main(int argc, char **argv, char **envp) {
     char *configfile = "/etc/tpop3d.conf", c;
     int na;
 
-    mtrace();
+    /*mtrace();*/ /* Memory debugging on glibc systems. */
 
     /* Read the options. */
     opterr = 0;
