@@ -6,7 +6,7 @@
  *
  */
 
-static const char rcsid[] = "$Id: util.c,v 1.5 2001/04/24 14:25:34 chris Exp $";
+static const char rcsid[] = "$Id: util.c,v 1.7 2001/06/06 14:50:53 chris Exp $";
 
 #ifdef HAVE_CONFIG_H
 #include "configuration.h"
@@ -46,23 +46,23 @@ void print_log(int priority, const char *fmt, ...) {
 }
 
 /* xwrite:
- * Write some data, taking account of short writes.
+ * Write some data, taking account of short writes and signals.
  */
 ssize_t xwrite(int fd, const void *buf, size_t count) {
     size_t c = count;
     const char *b = (const char*)buf;
     while (c > 0) {
-        int e = write(fd, b, count);
-        if (e > 0) {
+        int e = write(fd, b, c);
+        if (e >= 0) {
             c -= e;
             b += e;
-        } else return e;
+        } else if (errno != EINTR) return e;
     } while (c > 0);
     return count;
 }
 
 /* daemon:
- * Become a daemon. From "The Unix Programming FAQ", Andrew Gierth et al.
+ * Become a daemon. From `The Unix Programming FAQ', Andrew Gierth et al.
  */
 int daemon(int nochdir, int noclose) {
     switch (fork()) {
@@ -145,7 +145,8 @@ int write_file(int fd, int sck, size_t msgoffset, size_t skip, size_t msglength,
         if (!try_write(sck, p, q - p) || !try_write(sck, "\r\n", 2))
             goto write_failure;
         p = q + 1;
-    } while (*p != '\n');
+    } while (p < r && *p != '\n');
+
     ++p;
 
     errno = 0;
